@@ -88,7 +88,7 @@
 /* disable setting the x background for bug 7442 */
 //#define DISABLE_FOR_BUG7442
 
-struct _XfceDesktopPriv
+struct _XfceDesktopPrivate
 {
     GdkScreen *gscreen;
     WnckScreen *wnck_screen;
@@ -333,7 +333,9 @@ set_real_root_window_surface(GdkScreen *gscreen,
             GDK_PROP_MODE_REPLACE, (guchar *)&xid, 1);
     /* and set the root window's BG surface, because aterm is somewhat lame. */
     pattern = cairo_pattern_create_for_surface(surface);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_window_set_background_pattern(groot, pattern);
+G_GNUC_END_IGNORE_DEPRECATIONS
     cairo_pattern_destroy(pattern);
     /* there really should be a standard for this crap... */
 
@@ -361,8 +363,7 @@ create_bg_surface(GdkScreen *gscreen, gpointer user_data)
 
     TRACE("really entering");
 
-    w = gdk_screen_get_width(gscreen);
-    h = gdk_screen_get_height(gscreen);
+    xfdesktop_get_screen_dimensions (gscreen, &w, &h);
     gtk_widget_set_size_request(GTK_WIDGET(desktop), w, h);
     gtk_window_resize(GTK_WINDOW(desktop), w, h);
 
@@ -373,7 +374,9 @@ create_bg_surface(GdkScreen *gscreen, gpointer user_data)
                                                           CAIRO_CONTENT_COLOR_ALPHA, w, h);
 
     pattern = cairo_pattern_create_for_surface(desktop->priv->bg_surface);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_window_set_background_pattern(gtk_widget_get_window(GTK_WIDGET(desktop)), pattern);
+G_GNUC_END_IGNORE_DEPRECATIONS
     cairo_pattern_destroy(pattern);
 
     return desktop->priv->bg_surface;
@@ -523,8 +526,7 @@ backdrop_changed_cb(XfceBackdrop *backdrop, gpointer user_data)
                 rect.y = monitor_rect.y;
         }
 
-        rect.width = gdk_screen_get_width(gscreen);
-        rect.height = gdk_screen_get_height(gscreen);
+        xfdesktop_get_screen_dimensions (gscreen, &rect.width, &rect.height);
         XF_DEBUG("xinerama_stretch x %d, y %d, width %d, height %d",
                  rect.x, rect.y, rect.width, rect.height);
     } else {
@@ -836,7 +838,7 @@ screen_set_selection(XfceDesktop *desktop)
     Atom selection_atom, common_selection_atom, manager_atom;
 
     xwin = GDK_WINDOW_XID(gtk_widget_get_window(GTK_WIDGET(desktop)));
-    xscreen = gdk_screen_get_number(desktop->priv->gscreen);
+    xscreen = gdk_x11_screen_get_screen_number(desktop->priv->gscreen);
 
     g_snprintf(selection_name, 100, XFDESKTOP_SELECTION_FMT, xscreen);
     selection_atom = XInternAtom(gdk_x11_get_default_xdisplay(), selection_name, False);
@@ -891,7 +893,7 @@ screen_set_selection(XfceDesktop *desktop)
 /* gobject-related functions */
 
 
-G_DEFINE_TYPE(XfceDesktop, xfce_desktop, GTK_TYPE_WINDOW)
+G_DEFINE_TYPE_WITH_PRIVATE(XfceDesktop, xfce_desktop, GTK_TYPE_WINDOW)
 
 
 static void
@@ -900,8 +902,6 @@ xfce_desktop_class_init(XfceDesktopClass *klass)
     GObjectClass *gobject_class = (GObjectClass *)klass;
     GtkWidgetClass *widget_class = (GtkWidgetClass *)klass;
 
-    g_type_class_add_private(klass, sizeof(XfceDesktopPriv));
-
     gobject_class->finalize = xfce_desktop_finalize;
     gobject_class->set_property = xfce_desktop_set_property;
     gobject_class->get_property = xfce_desktop_get_property;
@@ -1011,8 +1011,7 @@ xfce_desktop_class_init(XfceDesktopClass *klass)
 static void
 xfce_desktop_init(XfceDesktop *desktop)
 {
-    desktop->priv = G_TYPE_INSTANCE_GET_PRIVATE(desktop, XFCE_TYPE_DESKTOP,
-                                                XfceDesktopPriv);
+    desktop->priv = xfce_desktop_get_instance_private(desktop);
 
     gtk_window_set_type_hint(GTK_WINDOW(desktop), GDK_WINDOW_TYPE_HINT_DESKTOP);
     /* Accept focus is needed for the menu pop up either by the menu key on
@@ -1158,8 +1157,7 @@ xfce_desktop_realize(GtkWidget *widget)
     TRACE("entering");
 
     gtk_window_set_screen(GTK_WINDOW(desktop), desktop->priv->gscreen);
-    sw = gdk_screen_get_width(desktop->priv->gscreen);
-    sh = gdk_screen_get_height(desktop->priv->gscreen);
+    xfdesktop_get_screen_dimensions (desktop->priv->gscreen, &sw, &sh);
 
     g_signal_connect(G_OBJECT(desktop->priv->gscreen),
                      "monitors-changed",
@@ -1170,7 +1168,7 @@ xfce_desktop_realize(GtkWidget *widget)
     GTK_WIDGET_CLASS(xfce_desktop_parent_class)->realize(widget);
 
     gtk_window_set_title(GTK_WINDOW(desktop), _("Desktop"));
-
+    gtk_window_set_decorated(GTK_WINDOW(desktop), FALSE);
     gtk_widget_set_size_request(GTK_WIDGET(desktop), sw, sh);
     gtk_window_move(GTK_WINDOW(desktop), 0, 0);
 
@@ -1195,7 +1193,7 @@ xfce_desktop_realize(GtkWidget *widget)
 
     screen_set_selection(desktop);
 
-    wnck_screen = wnck_screen_get(gdk_screen_get_number(desktop->priv->gscreen));
+    wnck_screen = wnck_screen_get(gdk_x11_screen_get_screen_number(desktop->priv->gscreen));
     desktop->priv->wnck_screen = wnck_screen;
 
     /* Watch for single workspace setting changes */
@@ -1270,7 +1268,9 @@ xfce_desktop_unrealize(GtkWidget *widget)
 #ifndef DISABLE_FOR_BUG7442
     gdk_property_delete(groot, gdk_atom_intern("_XROOTPMAP_ID", FALSE));
     gdk_property_delete(groot, gdk_atom_intern("ESETROOT_PMAP_ID", FALSE));
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
     gdk_window_set_background_pattern(groot, NULL);
+G_GNUC_END_IGNORE_DEPRECATIONS
 #endif
 
     if(desktop->priv->workspaces) {
@@ -1428,8 +1428,10 @@ style_refresh_cb(gpointer *w)
 
     if(desktop->priv->bg_surface) {
         pattern = cairo_pattern_create_for_surface(desktop->priv->bg_surface);
+G_GNUC_BEGIN_IGNORE_DEPRECATIONS
         gdk_window_set_background_pattern(gtk_widget_get_window(GTK_WIDGET(desktop)),
                                           pattern);
+G_GNUC_END_IGNORE_DEPRECATIONS
         cairo_pattern_destroy(pattern);
     }
 
@@ -1570,7 +1572,7 @@ xfce_desktop_new(GdkScreen *gscreen,
     gtk_window_set_screen(GTK_WINDOW(desktop), gscreen);
     desktop->priv->gscreen = gscreen;
 
-    desktop->priv->channel = g_object_ref(G_OBJECT(channel));
+    desktop->priv->channel = XFCONF_CHANNEL(g_object_ref(G_OBJECT(channel)));
     desktop->priv->property_prefix = g_strdup(property_prefix);
 
     xfce_desktop_connect_settings(desktop);
@@ -1588,22 +1590,6 @@ xfce_desktop_get_n_monitors(XfceDesktop *desktop)
     return gdk_display_get_n_monitors(gdk_screen_get_display(desktop->priv->gscreen));
 }
 
-gint
-xfce_desktop_get_width(XfceDesktop *desktop)
-{
-    g_return_val_if_fail(XFCE_IS_DESKTOP(desktop), -1);
-
-    return gdk_screen_get_width(desktop->priv->gscreen);
-}
-
-gint
-xfce_desktop_get_height(XfceDesktop *desktop)
-{
-    g_return_val_if_fail(XFCE_IS_DESKTOP(desktop), -1);
-
-    return gdk_screen_get_height(desktop->priv->gscreen);
-}
-
 void
 xfce_desktop_set_icon_style(XfceDesktop *desktop,
                             XfceDesktopIconStyle style)
@@ -1949,23 +1935,10 @@ xfce_desktop_refresh(XfceDesktop *desktop, gboolean advance_wallpaper)
             backdrop_changed_cb(backdrop, desktop);
         }
     }
-
-    /* If we're only advancing the wallpaper we can exit here */
-    if(advance_wallpaper)
-        return;
-
-#ifdef ENABLE_DESKTOP_ICONS
-    /* reload icon view */
-    if(desktop->priv->icon_view) {
-        gtk_widget_destroy(desktop->priv->icon_view);
-        desktop->priv->icon_view = NULL;
-    }
-    xfce_desktop_setup_icon_view(desktop);
-#endif
-
 }
 
-void xfce_desktop_arrange_icons(XfceDesktop *desktop)
+void
+xfce_desktop_arrange_icons(XfceDesktop *desktop)
 {
     g_return_if_fail(XFCE_IS_DESKTOP(desktop));
 
@@ -1975,3 +1948,22 @@ void xfce_desktop_arrange_icons(XfceDesktop *desktop)
     xfdesktop_icon_view_sort_icons(XFDESKTOP_ICON_VIEW(desktop->priv->icon_view));
 #endif
 }
+
+gboolean
+xfce_desktop_get_cycle_backdrop(XfceDesktop *desktop)
+{
+    gint monitor;
+    XfceWorkspace *workspace;
+    XfceBackdrop  *backdrop;
+
+    g_return_val_if_fail(XFCE_IS_DESKTOP(desktop), FALSE);
+
+    xfce_gdk_screen_get_active(&monitor);
+    if(&monitor == NULL)
+        return FALSE;
+
+    workspace = desktop->priv->workspaces[desktop->priv->current_workspace];
+    backdrop = xfce_workspace_get_backdrop(workspace, monitor);
+
+    return xfce_backdrop_get_cycle_backdrop(backdrop);
+}
